@@ -12,12 +12,12 @@ impl OutputCli for ConcatParser<'_> {}
 impl InputCli for ConcatParser<'_> {}
 
 pub(in crate::cli) struct ConcatParser<'a> {
-    matches: &'a ArgMatches<'a>,
+    matches: &'a ArgMatches,
     input_dir: Option<PathBuf>,
 }
 
 impl<'a> ConcatParser<'a> {
-    pub(in crate::cli) fn new(matches: &'a ArgMatches<'a>) -> Self {
+    pub(in crate::cli) fn new(matches: &'a ArgMatches) -> Self {
         Self {
             matches,
             input_dir: None,
@@ -49,9 +49,10 @@ impl<'a> ConcatParser<'a> {
             &datatype,
         );
 
-        self.check_output_dir_exist(&dir);
-        let mut concat = ConcatHandler::new(&input_fmt, &output, &output_fmt, &part_fmt);
+        let is_overwrite = self.parse_overwrite_opts(self.matches);
+        self.check_output_dir_exist(&dir, is_overwrite);
 
+        let mut concat = ConcatHandler::new(&input_fmt, &output, &output_fmt, &part_fmt);
         concat.concat_alignment(&mut files, &datatype);
     }
 }
