@@ -11,7 +11,7 @@ impl OutputCli for IdParser<'_> {}
 impl InputPrint for IdParser<'_> {}
 
 pub(in crate::cli) struct IdParser<'a> {
-    matches: &'a ArgMatches<'a>,
+    matches: &'a ArgMatches,
     input_dir: Option<PathBuf>,
 }
 
@@ -45,11 +45,12 @@ impl<'a> IdParser<'a> {
 
         let output = self.parse_output(self.matches);
         let output = output.with_extension("txt");
-        self.check_output_file_exist(&output);
+        let is_overwrite = self.parse_overwrite_opts(self.matches);
+        self.check_output_file_exist(&output, is_overwrite);
         let id = Id::new(&output, &input_fmt, &datatype);
         if self.matches.is_present("map") {
             let map_fname = self.create_map_fname(&output);
-            self.check_output_file_exist(&map_fname);
+            self.check_output_file_exist(&map_fname, is_overwrite);
             id.map_id(&files, &map_fname);
         } else {
             id.generate_id(&files);
