@@ -4,6 +4,7 @@ mod convert;
 mod extract;
 mod filter;
 mod id;
+mod partition;
 mod rename;
 mod split;
 mod summarize;
@@ -15,6 +16,7 @@ use std::io::Result;
 
 use std::path::{Path, PathBuf};
 
+use ansi_term::Colour::Red;
 use clap::ArgMatches;
 use dialoguer::{theme::ColorfulTheme, Confirm};
 use glob::glob;
@@ -29,6 +31,7 @@ use crate::cli::convert::ConvertParser;
 use crate::cli::extract::ExtractParser;
 use crate::cli::filter::FilterParser;
 use crate::cli::id::IdParser;
+use crate::cli::partition::PartParser;
 use crate::cli::rename::RenameParser;
 use crate::cli::split::SplitParser;
 use crate::cli::summarize::SummaryParser;
@@ -45,15 +48,16 @@ pub fn parse_cli(version: &str) {
     setup_logger().expect("Failed setting up a log file.");
     utils::print_welcome_text(version);
     match args.subcommand() {
-        ("convert", Some(convert_matches)) => ConvertParser::new(convert_matches).convert(),
-        ("concat", Some(concat_matches)) => ConcatParser::new(concat_matches).concat(),
-        ("filter", Some(pick_matches)) => FilterParser::new(pick_matches).filter(),
-        ("id", Some(id_matches)) => IdParser::new(id_matches).get_id(),
-        ("extract", Some(extract_matches)) => ExtractParser::new(extract_matches).extract(),
-        ("rename", Some(rename_matches)) => RenameParser::new(rename_matches).rename(),
-        ("summary", Some(stats_matches)) => SummaryParser::new(stats_matches).stats(),
-        ("translate", Some(trans_matches)) => TranslateParser::new(trans_matches).translate(),
-        ("split", Some(split_matches)) => SplitParser::new(split_matches).split(),
+        Some(("convert", convert_matches)) => ConvertParser::new(convert_matches).convert(),
+        Some(("concat", concat_matches)) => ConcatParser::new(concat_matches).concat(),
+        Some(("filter", pick_matches)) => FilterParser::new(pick_matches).filter(),
+        Some(("id", id_matches)) => IdParser::new(id_matches).get_id(),
+        Some(("extract", extract_matches)) => ExtractParser::new(extract_matches).extract(),
+        Some(("rename", rename_matches)) => RenameParser::new(rename_matches).rename(),
+        Some(("summary", stats_matches)) => SummaryParser::new(stats_matches).stats(),
+        Some(("translate", trans_matches)) => TranslateParser::new(trans_matches).translate(),
+        Some(("split", split_matches)) => SplitParser::new(split_matches).split(),
+        Some(("partition", part_matches)) => PartParser::new(part_matches).convert(),
         _ => unreachable!("Invalid subcommands!"),
     }
 }
@@ -168,6 +172,10 @@ trait InputCli {
             _ => unreachable!(),
         }
     }
+
+    fn parse_overwrite_opts(&self, matches: &ArgMatches) -> bool {
+        matches.is_present("overwrite")
+    }
 }
 
 trait InputPrint {
@@ -231,26 +239,38 @@ trait OutputCli {
         }
     }
 
-    fn check_output_file_exist(&self, path: &Path) {
-        let error_msg = format!("Output file already exists: {}", path.display());
-        check_output_path!(
-            is_file,
-            remove_file,
-            path,
-            error_msg,
-            "Failed removing files"
-        );
+    fn check_output_dir_exist(&self, path: &Path, overwrite: bool) {
+        let rm_err_msg = "Failed removing a directory";
+        if overwrite {
+            if path.is_dir() {
+                log::warn!(
+                    "{} Removing existing directory: {}\n",
+                    Red.paint("WARNING!"),
+                    path.display()
+                );
+                fs::remove_dir_all(path).expect(rm_err_msg);
+            }
+        } else {
+            let error_msg = format!("Output dir already exists: {}. Remove?", path.display());
+            check_output_path!(is_dir, remove_dir_all, path, error_msg, rm_err_msg)
+        }
     }
 
-    fn check_output_dir_exist(&self, path: &Path) {
-        let error_msg = format!("Output dir already exists: {}", path.display());
-        check_output_path!(
-            is_dir,
-            remove_dir_all,
-            path,
-            error_msg,
-            "Failed removing a directory"
-        )
+    fn check_output_file_exist(&self, path: &Path, overwrite: bool) {
+        let rm_err_msg = "Failed removing existing output files";
+        if overwrite {
+            if path.is_file() {
+                log::warn!(
+                    "{} Overwriting existing files: {}\n",
+                    Red.paint("WARNING!"),
+                    path.display()
+                );
+                fs::remove_file(path).expect(rm_err_msg);
+            }
+        } else {
+            let error_msg = format!("Output file already exists: {}. Remove?", path.display());
+            check_output_path!(is_file, remove_file, path, error_msg, rm_err_msg);
+        }
     }
 }
 
@@ -286,6 +306,10 @@ trait ConcatCli {
         }
     }
 
+    fn parse_uncheck_part_flag(&self, matches: &ArgMatches) -> bool {
+        matches.is_present("uncheck")
+    }
+
     fn parse_partition_fmt_codon(&self, part_fmt: &str) -> PartitionFmt {
         match part_fmt {
             "charset" => PartitionFmt::CharsetCodon,
