@@ -36,11 +36,11 @@ impl ConcatCli for SplitParser<'_> {
 }
 
 pub(in crate::cli) struct SplitParser<'a> {
-    matches: &'a ArgMatches<'a>,
+    matches: &'a ArgMatches,
 }
 
 impl<'a> SplitParser<'a> {
-    pub(in crate::cli) fn new(matches: &'a ArgMatches<'a>) -> Self {
+    pub(in crate::cli) fn new(matches: &'a ArgMatches) -> Self {
         Self { matches }
     }
 
@@ -50,14 +50,23 @@ impl<'a> SplitParser<'a> {
         let datatype = self.parse_datatype(self.matches);
         let output_fmt = self.parse_output_fmt(self.matches);
         let output = self.parse_output(self.matches);
-        let partitions = self.parse_partition_path();
+
+        // If users do not specify input partition.
+        // Assume partition is in the sequence file.
+        let partitions = if self.matches.is_present("input-partition") {
+            self.parse_partition_path()
+        } else {
+            PathBuf::from(&input)
+        };
         let part_fmt = self.parse_part_fmt(&partitions);
         let prefix = self.parse_prefix_input();
         let task_desc = "Alignment splitting";
         self.print_input(&None::<PathBuf>, task_desc, 1, &input_fmt, &datatype);
-        self.check_output_dir_exist(&output);
+        let is_overwrite = self.parse_overwrite_opts(self.matches);
+        let is_uncheck = self.parse_uncheck_part_flag(self.matches);
+        self.check_output_dir_exist(&output, is_overwrite);
         let split = Splitter::new(&input, &datatype, &input_fmt, &output, &output_fmt);
-        split.split_alignment(&partitions, &part_fmt, &prefix);
+        split.split_alignment(&partitions, &part_fmt, &prefix, is_uncheck);
     }
 
     fn parse_input_path(&self) -> PathBuf {
