@@ -11,7 +11,7 @@ impl InputPrint for SummaryParser<'_> {}
 impl OutputCli for SummaryParser<'_> {}
 
 pub(in crate::cli) struct SummaryParser<'a> {
-    matches: &'a ArgMatches<'a>,
+    matches: &'a ArgMatches,
     interval: usize,
     input_fmt: InputFmt,
     datatype: DataType,
@@ -19,7 +19,7 @@ pub(in crate::cli) struct SummaryParser<'a> {
 }
 
 impl<'a> SummaryParser<'a> {
-    pub(in crate::cli) fn new(matches: &'a ArgMatches<'a>) -> Self {
+    pub(in crate::cli) fn new(matches: &'a ArgMatches) -> Self {
         Self {
             matches,
             interval: 0,
@@ -52,7 +52,8 @@ impl<'a> SummaryParser<'a> {
         );
 
         let output = self.parse_output(self.matches);
-        self.check_output_dir_exist(&output);
+        let is_overwrite = self.parse_overwrite_opts(self.matches);
+        self.check_output_dir_exist(&output, is_overwrite);
         SeqStats::new(&self.input_fmt, &output, self.interval, &self.datatype)
             .get_stats_all(&files, &prefix);
     }
