@@ -19,13 +19,13 @@ macro_rules! parse_table_args {
 }
 
 pub(in crate::cli) struct TranslateParser<'a> {
-    matches: &'a ArgMatches<'a>,
+    matches: &'a ArgMatches,
     input_dir: Option<PathBuf>,
     trans_table: GeneticCodes,
 }
 
 impl<'a> TranslateParser<'a> {
-    pub(in crate::cli) fn new(matches: &'a ArgMatches<'a>) -> Self {
+    pub(in crate::cli) fn new(matches: &'a ArgMatches) -> Self {
         Self {
             matches,
             input_dir: None,
@@ -64,7 +64,8 @@ impl<'a> TranslateParser<'a> {
             &datatype,
         );
 
-        self.check_output_dir_exist(&outdir);
+        let overwrite = self.parse_overwrite_opts(self.matches);
+        self.check_output_dir_exist(&outdir, overwrite);
         log::info!("{}", Yellow.paint("Params"));
         self.parse_trans_table();
         let translate = Translate::new(&self.trans_table, &input_fmt, &datatype, &output_fmt);
