@@ -3,12 +3,18 @@ pub mod convert;
 pub mod extract;
 pub mod filter;
 pub mod id;
+pub mod partition;
 pub mod rename;
 pub mod split;
 pub mod summarize;
 pub mod translate;
 
+use std::path::Path;
+
+use ansi_term::Colour::Yellow;
+
 use crate::helper::types::OutputFmt;
+use crate::helper::utils;
 
 macro_rules! log_output_fmt {
     ($ftype: expr) => {
@@ -28,3 +34,11 @@ trait OutputPrint {
         }
     }
 }
+
+trait PartitionPrint {
+    fn print_partition_info(&self, part_path: &Path, part_counts: &usize) {
+        log::info!("{}", Yellow.paint("Partitions"));
+        log::info!("{:18}: {}", "Partition counts", utils::fmt_num(part_counts));
+        log::info!("{:18}: {}\n", "File path", part_path.display());
+    }
+}
