@@ -5,7 +5,7 @@ use ansi_term::Colour::Yellow;
 use indexmap::IndexMap;
 use rayon::prelude::*;
 
-use crate::core::OutputPrint;
+use crate::core::{OutputPrint, PartitionPrint};
 use crate::helper::filenames;
 use crate::helper::sequence::Sequence;
 use crate::helper::types::{DataType, Header, InputFmt, OutputFmt, PartitionFmt, SeqMatrix};
@@ -14,6 +14,7 @@ use crate::parser::partition::PartitionParser;
 use crate::writer::sequences::SeqWriter;
 
 impl OutputPrint for Splitter<'_> {}
+impl PartitionPrint for Splitter<'_> {}
 
 pub struct Splitter<'a> {
     input: &'a Path,
@@ -45,8 +46,9 @@ impl<'a> Splitter<'a> {
         part_path: &Path,
         partition_fmt: &PartitionFmt,
         prefix: &Option<String>,
+        is_uncheck: bool,
     ) {
-        let partitions = PartitionParser::new(part_path, partition_fmt).parse();
+        let partitions = PartitionParser::new(part_path, partition_fmt, is_uncheck).parse();
         self.print_partition_info(part_path, &partitions.len());
         let spin = utils::set_spinner();
         spin.set_message("Parsing input sequence file...");
@@ -67,7 +69,7 @@ impl<'a> Splitter<'a> {
             let filename = self.parse_filename(&part.gene, prefix);
             let output_path =
                 filenames::create_output_fname(self.output, &filename, self.output_fmt);
-            let mut out = SeqWriter::new(&output_path, &matrix, &header, None, &PartitionFmt::None);
+            let mut out = SeqWriter::new(&output_path, &matrix, &header);
             out.write_sequence(self.output_fmt)
                 .expect("Failed writing the output file");
             file_counts.fetch_add(1, Ordering::Relaxed);
@@ -80,16 +82,11 @@ impl<'a> Splitter<'a> {
     // Generate a filename for each locus based on the locus name
     // We get rid of any characters that are not alphanumeric, underscore, or dash
     fn parse_filename(&self, gene_name: &str, prefix: &Option<String>) -> PathBuf {
-        let mut filename = match prefix {
+        let filename = match prefix {
             Some(prefix) => format!("{}_{}", prefix, gene_name),
             None => String::from(gene_name),
         };
 
-        filename.retain(|c| !r#"()/\,"';:?!"#.contains(c));
-        if filename.contains('.') {
-            filename = filename.replace('.', "_");
-        }
-
         PathBuf::from(filename)
     }
 
@@ -127,12 +124,6 @@ impl<'a> Splitter<'a> {
         matrix
     }
 
-    fn print_partition_info(&self, part_path: &Path, part_counts: &usize) {
-        log::info!("{}", Yellow.paint("Partitions"));
-        log::info!("{:18}: {}", "Partition counts", utils::fmt_num(part_counts));
-        log::info!("{:18}: {}\n", "File path", part_path.display());
-    }
-
     fn print_output_info(&self, file_counts: usize) {
         log::info!("{}", Yellow.paint("Output"));
         log::info!("{:18}: {}", "File counts", utils::fmt_num(&file_counts));
@@ -160,12 +151,12 @@ mod test {
     #[test]
     fn test_parse_filename() {
         input_split!(split, "test_files/test.fasta");
+        // assert_eq!(
+        //     split.parse_filename(r#"'test!?'"#, &None),
+        //     PathBuf::from("test")
+        // );
         assert_eq!(
-            split.parse_filename(r#"'test!?'"#, &None),
-            PathBuf::from("test")
-        );
-        assert_eq!(
-            split.parse_filename(r#"'test!?'"#, &Some("test".to_string())),
+            split.parse_filename("test", &Some("test".to_string())),
             PathBuf::from("test_test")
         );
     }
