@@ -24,9 +24,9 @@ pub enum PartitionFmt {
     NexusCodon,
     Raxml,
     RaxmlCodon,
-    None,
 }
 
+#[derive(PartialEq)]
 pub enum DataType {
     Dna,
     Aa,
