@@ -3,6 +3,7 @@ use std::io::prelude::*;
 use std::io::{BufReader, Read};
 use std::path::Path;
 
+use ansi_term::Colour::Red;
 use indexmap::{IndexMap, IndexSet};
 use lazy_static::lazy_static;
 use nom::{bytes::complete, character, sequence, IResult};
@@ -11,6 +12,7 @@ use regex::Regex;
 use crate::helper::alphabet;
 use crate::helper::sequence::SeqCheck;
 use crate::helper::types::{DataType, Header, SeqMatrix};
+use crate::parser;
 
 pub struct Nexus<'a> {
     input: &'a Path,
@@ -58,19 +60,7 @@ impl<'a> Nexus<'a> {
             _ => (),
         });
 
-        assert!(
-            ids.len() == self.header.ntax,
-            "Failed parsing {}. \
-        The number of taxa does not match the information in the header.\
-            In the header: {} \
-            and taxa found: {}. \
-            Please check if the header matches the sample count in the nexus file. \
-            Or no duplicate IDs are present.
-        ",
-            self.input.display(),
-            self.header.ntax,
-            ids.len()
-        );
+        parser::warn_duplicate_ids!(self, ids);
 
         ids
     }
@@ -126,24 +116,11 @@ impl<'a> Nexus<'a> {
             if self.interleave {
                 self.insert_matrix_interleave(id.to_string(), seq.to_string());
             } else {
-                self.insert_matrix(id.to_string(), seq.to_string());
+                parser::insert_matrix!(self, id, seq);
             }
         });
     }
 
-    fn insert_matrix(&mut self, id: String, dna: String) {
-        match self.matrix.get(&id) {
-            Some(_) => panic!(
-                "Found duplicate samples for file {}. First duplicate found: {}",
-                self.input.display(),
-                id
-            ),
-            None => {
-                self.matrix.insert(id, dna);
-            }
-        }
-    }
-
     fn insert_matrix_interleave(&mut self, id: String, dna: String) {
         match self.matrix.get_mut(&id) {
             Some(value) => value.push_str(&dna),
@@ -162,22 +139,26 @@ impl<'a> Nexus<'a> {
         }
     }
 
+    #[inline]
     fn parse_datatype(&self, input: &str) -> String {
         let tag: IResult<&str, &str> =
             sequence::preceded(complete::tag("datatype="), character::complete::alpha1)(input);
         self.parse_string(tag)
     }
 
+    #[inline]
     fn parse_gap(&self, input: &str) -> char {
         let gap = input.replace("gap=", "");
         self.parse_char(&gap)
     }
 
+    #[inline]
     fn parse_missing(&self, input: &str) -> char {
         let missing = input.replace("missing=", "");
         self.parse_char(&missing)
     }
 
+    #[inline]
     fn parse_string(&self, tag: IResult<&str, &str>) -> String {
         let mut text = String::new();
         self.convert_nomtag_to_string(tag, &mut text);
@@ -215,6 +196,7 @@ impl<'a> Nexus<'a> {
         }
     }
 
+    #[inline]
     fn check_nexus(&self, line: &str) {
         if !line.to_lowercase().starts_with("#nexus") {
             panic!("The file {} is invalid nexus format.", self.input.display());
@@ -422,14 +404,6 @@ mod test {
         nex.parse();
     }
 
-    #[test]
-    #[should_panic]
-    fn test_nexus_id_duplicate_panic() {
-        let sample = Path::new("test_files/duplicates.nex");
-        let mut nex = Nexus::new(sample, &DNA);
-        nex.parse_only_id();
-    }
-
     #[test]
     #[should_panic]
     fn test_nexus_space_panic() {
